"""Permissions wrappers."""
from dis_snek import InteractionContext, Permissions

from jarvis.config import get_config


def user_is_bot_admin() -> bool:
    """Check if a user is a JARVIS admin."""

    async def predicate(ctx: InteractionContext) -> bool:
        """Command check predicate."""
        if getattr(get_config(), "admins", None):
            return ctx.author.id in get_config().admins
        else:
            return False

    return predicate


def admin_or_permissions(*perms: list) -> bool:
    """Check if a user is an admin or has other perms."""

    async def predicate(ctx: InteractionContext) -> bool:
        """Extended check predicate."""  # noqa: D401
        is_admin = ctx.author.has_permission(Permissions.ADMINISTRATOR)
        has_other = any(ctx.author.has_permission(perm) for perm in perms)
        return is_admin or has_other

    return predicate
